@@ -27,13 +27,13 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * This software consists of voluntary contributions made by many individuals
+ * This software consists of voluntary contributions made by many individuals 
  * on behalf of the Hypersonic SQL Group.
  *
  *
  * For work added by the HSQL Development Group:
  *
- * Copyright (c) 2001-2008, The HSQL Development Group
+ * Copyright (c) 2001-2005, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -114,7 +114,7 @@ public class Trace {
     public static final int
 
     //
-    LOCK_FILE_ACQUISITION_FAILURE           = 1,
+    DATABASE_ALREADY_IN_USE                 = 1,
     CONNECTION_IS_CLOSED                    = 2,
     CONNECTION_IS_BROKEN                    = 3,
     DATABASE_IS_SHUTDOWN                    = 4,
@@ -369,9 +369,7 @@ public class Trace {
     COLUMN_SIZE_REQUIRED                    = 253,
     INVALID_SIZE_PRECISION                  = 254,
     CANNOT_CONNECT_TABLE                    = 255,
-    INVALID_FILE_ACCESS_CLASS               = 256,
-    INVALID_STORAGE_CLASS                   = 257,
-    LAST_ERROR_HANDLE                       = 258;
+    LAST_ERROR_HANDLE                       = 256;
 
     //
     static String MESSAGE_TAG = "$$";
